summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorVille Skyttä <ville.skytta@iki.fi>2021-11-14 00:44:47 +0200
committerVille Skyttä <ville.skytta@iki.fi>2023-08-12 19:13:48 +0300
commit5f14673f62de501043247982cf7cfc4cd8b7cf3a (patch)
treef680cd265476b1838e29c58a69913fc4e452f233
parentc27ab1eb76bd2e5ab9fcc9a26f6c67ca8e02db17 (diff)
*: spelling fixes
-rw-r--r--ChangeLog4
-rwxr-xr-xautotests/t-xdg-open.sh2
-rw-r--r--scripts/xdg-mime.in4
-rwxr-xr-xtests/doc_gen.pl2
-rw-r--r--tests/include/testcontrol.sh2
-rw-r--r--tests/include/testfuncs.sh4
-rwxr-xr-xtests/xdg-mime/t.02-query_missing_file2
-rwxr-xr-xtests/xdg-mime/t.12-user_install_missing_file2
-rwxr-xr-xtests/xdg-mime/t.22-system_install_missing_file2
9 files changed, 12 insertions, 12 deletions
diff --git a/ChangeLog b/ChangeLog
index 1c6b4c1..01e961d 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -364,7 +364,7 @@
twice. Thanks to David Benjamin.
2010-09-24 Fathi Boudra <fabo@freedesktop.org>
- * xdg-email: Fix e-mail attachements support with Thunderbird3 (BR13435)
+ * xdg-email: Fix e-mail attachments support with Thunderbird3 (BR13435)
2010-09-24 Fathi Boudra <fabo@freedesktop.org>
* xdg-mime: update the required section "[Added Associations]"
@@ -526,7 +526,7 @@
* Add KDE 4 support to xdg-email (BR17268)
2009-07-26 Fathi Boudra <fabo@freedesktop.org>
- * Sleep for 50s instead of 59s to avoid to froze the seesion (BR19414)
+ * Sleep for 50s instead of 59s to avoid to froze the session (BR19414)
2009-07-26 Fathi Boudra <fabo@freedesktop.org>
* Fix a race condition in xdg-screensaver (BR19382)
diff --git a/autotests/t-xdg-open.sh b/autotests/t-xdg-open.sh
index 0d4b8d2..279eb77 100755
--- a/autotests/t-xdg-open.sh
+++ b/autotests/t-xdg-open.sh
@@ -23,7 +23,7 @@ elif [ $# = 3 ] && [ "$1" = query ] && [ "$2" = default ] && \
[ "$3" = '$mimetype' ]; then
echo '$handler'.desktop
else
- echo "unexpected mock invokation: xdg-mime $*" >&2
+ echo "unexpected mock invocation: xdg-mime $*" >&2
exit 1
fi
'
diff --git a/scripts/xdg-mime.in b/scripts/xdg-mime.in
index 49ff131..9bb047e 100644
--- a/scripts/xdg-mime.in
+++ b/scripts/xdg-mime.in
@@ -613,7 +613,7 @@ if [ "$action" = "info" ]; then
info_generic "$filename"
;;
esac
- exit_failure_operation_impossible "no method available for quering MIME type of '$filename'"
+ exit_failure_operation_impossible "no method available for querying MIME type of '$filename'"
fi
if [ "$action" = "defapp" ]; then
@@ -625,7 +625,7 @@ if [ "$action" = "defapp" ]; then
defapp_generic "$mimetype"
- exit_failure_operation_impossible "no method available for quering default application for '$mimetype'"
+ exit_failure_operation_impossible "no method available for querying default application for '$mimetype'"
fi
vendor=true
diff --git a/tests/doc_gen.pl b/tests/doc_gen.pl
index 50d134d..f5a2c00 100755
--- a/tests/doc_gen.pl
+++ b/tests/doc_gen.pl
@@ -100,7 +100,7 @@ for $f ( @test_files ) {
$txt =~ s/\"//g;
print HTM "<p>$txt</p>\n";
}
- #find initilization
+ #find initialization
elsif ( m/test_init/ ) {
print HTM "<h2>Dependencies</h2>\n";
$state = 'INIT';
diff --git a/tests/include/testcontrol.sh b/tests/include/testcontrol.sh
index cdd1610..32ebff9 100644
--- a/tests/include/testcontrol.sh
+++ b/tests/include/testcontrol.sh
@@ -34,7 +34,7 @@ repeat_test() {
## USAGE:
# repeat_test test_func N var1 ... varN var1_value1 ... var1_valueM ... varN_valueM
# where N is the number of values to substiute and M is the number of
-# values each varable takes
+# values each variable takes
#
# EXAMPLE
# repeat_test copy_file 2 INPUT OUTPUT infile1 infile2 outfile1 outfile2
diff --git a/tests/xdg-mime/t.02-query_missing_file b/tests/xdg-mime/t.02-query_missing_file
index 08045d5..ad5fc85 100755
--- a/tests/xdg-mime/t.02-query_missing_file
+++ b/tests/xdg-mime/t.02-query_missing_file
@@ -5,7 +5,7 @@
. "$XDG_TEST_DIR/include/testcontrol.sh"
test_query_missing_file() {
-INPUT_FILE='non-existant-file.xml'
+INPUT_FILE='non-existent-file.xml'
test_start "$FUNCNAME: verify correct error for missing file: $INPUT_FILE"
test_purpose "Verify that the correct error is generated when the mime file is missing. This is bug 7123 case 1"
diff --git a/tests/xdg-mime/t.12-user_install_missing_file b/tests/xdg-mime/t.12-user_install_missing_file
index a2bd1a2..0512ad5 100755
--- a/tests/xdg-mime/t.12-user_install_missing_file
+++ b/tests/xdg-mime/t.12-user_install_missing_file
@@ -4,7 +4,7 @@
. "$XDG_TEST_DIR/include/testcontrol.sh"
test_user_install_missing_file() {
-INPUT_FILE='non-existant-file.xml'
+INPUT_FILE='non-existent-file.xml'
test_start "$FUNCNAME: install mime type as user with missing file $INPUT_FILE"
test_purpose "Verify that the correct error is generated when the mime file is missing."
diff --git a/tests/xdg-mime/t.22-system_install_missing_file b/tests/xdg-mime/t.22-system_install_missing_file
index 7a6233d..ce35ed5 100755
--- a/tests/xdg-mime/t.22-system_install_missing_file
+++ b/tests/xdg-mime/t.22-system_install_missing_file
@@ -5,7 +5,7 @@
. "$XDG_TEST_DIR/include/testcontrol.sh"
test_system_install_missing_file() {
-INPUT_FILE='non-existant-file.xml'
+INPUT_FILE='non-existent-file.xml'
test_start "$FUNCNAME: install mime type as system with missing file $INPUT_FILE"
test_purpose "Verify that the correct error is generated when the mime file is missing."
diff --git a/tests/include/testfuncs.sh b/tests/include/testfuncs.sh
index d8d73e5..dd7cdaa 100644
--- a/tests/include/testfuncs.sh
+++ b/tests/include/testfuncs.sh
@@ -59,11 +59,11 @@ test_status() {
## Called after test_init()
test_procedure() {
verify_test_context
## Make sure nothing screwed up in initilization
if [ "$TEST_STATUS" != "PASS" ]; then
# Something failed before we could get to the test.
FAIL=N
- test_result NORESULT "Initilization failed!"
+ test_result NORESULT "Initialization failed!"
fi
}
@@ -59,11 +59,11 @@ test_status() {
test_procedure() {
verify_test_context
- ## Make sure nothing screwed up in initilization
+ ## Make sure nothing screwed up in initialization
if [ "$TEST_STATUS" != "PASS" ]; then
# Something failed before we could get to the test.